@@ -244,6 +244,9 @@ local function checkValue(parent, child, mark, errs)
                 local knode = vm.compileNode(pfield.name)
                 local cvalues = vm.getTableValue(uri, tnode, knode, true)
                 if not cvalues then
+                    if pfield.optional then
+                        goto continue
+                    end
                     if errs then
                         errs[#errs+1] = 'TYPE_ERROR_TABLE_NO_FIELD'
                         errs[#errs+1] = pfield.name
@@ -260,6 +263,7 @@ local function checkValue(parent, child, mark, errs)
                     end
                     return false
                 end
+                ::continue::
             end
         end
         return true
@@ -369,7 +373,12 @@ function vm.isSubType(uri, child, parent, mark, errs)
     elseif child.type == 'vm.node' then
         if config.get(uri, 'Lua.type.weakUnionCheck') then
             local hasKnownType = 0
+            local i = 0
             for n in child:eachObject() do
+                i = i + 1
+                if i > 100 then
+                    break
+                end
                 if vm.getNodeName(n) then
                     local res = vm.isSubType(uri, n, parent, mark, errs)
                     if res == true then
@@ -393,7 +402,12 @@ function vm.isSubType(uri, child, parent, mark, errs)
         else
             local weakNil = config.get(uri, 'Lua.type.weakNilCheck')
             local skipTable
+            local i = 0
             for n in child:eachObject() do
+                i = i + 1
+                if i > 100 then
+                    break
+                end
                 if skipTable == nil and n.type == "table" and parent.type == "vm.node" then -- skip table type check if child has class
                     ---@cast parent vm.node
                     for _, c in ipairs(child) do
@@ -458,7 +472,12 @@ function vm.isSubType(uri, child, parent, mark, errs)
         parent = global
     elseif parent.type == 'vm.node' then
         local hasKnownType = 0
+        local i = 0
         for n in parent:eachObject() do
+            i = i + 1
+            if i > 100 then
+                break
+            end
             if vm.getNodeName(n) then
                 local res = vm.isSubType(uri, child, n, mark, errs)
                 if res == true then
